@@ -5,17 +5,16 @@ import shutil
 import subprocess
 import sys
 from pathlib import Path
-from importlib import resources
 
 
 def init_command():
     """Scaffold data/ and eval/ directories, create sample metrics and suites."""
     print("Initializing TrainLoop Evaluations...")
 
-    # Get the path to the scaffold directory
-    scaffold_path = resources.files("trainloop_cli").joinpath("../scaffold").resolve()
-
-    print(f"scaffold_path: {scaffold_path}")
+    # Get the path to the scaffold directory inside the package
+    current_file = Path(__file__)
+    # The scaffold is inside the trainloop_cli package
+    scaffold_dir = current_file.parent.parent / "scaffold"
 
     # Get destination directory (current working directory)
     dest_dir = Path.cwd()
@@ -28,38 +27,23 @@ def init_command():
         )
         sys.exit(1)
 
+    # Check if scaffold directory exists
+    if not scaffold_dir.exists() or not (scaffold_dir / "trainloop").exists():
+        print(f"Error: Could not find scaffold templates at {scaffold_dir}")
+        sys.exit(1)
+
     # Copy the scaffold directory to the trainloop directory
-    shutil.copytree(scaffold_path / "trainloop", trainloop_dir)
+    shutil.copytree(scaffold_dir / "trainloop", trainloop_dir)
 
-    # Check for .env file and create or update if needed
-    env_file = dest_dir / ".env"
-    env_var_name = "TRAINLOOP_DATA_FOLDER"
-    env_var_value = "trainloop/data"
-
-    if not env_file.exists():
-        # Try .env.local first
-        env_file = dest_dir / ".env.local"
-
-    if not env_file.exists():
-        # Create new .env file
-        with open(env_file, "w", encoding="utf-8") as f:
-            f.write("# Remove the below to stop collecting data\n")
-            f.write(f"{env_var_name}={env_var_value}\n")
-        print("Created .env file with TRAINLOOP_DATA_FOLDER environment variable")
-    else:
-        # Check if variable exists in env file
-        with open(env_file, "r", encoding="utf-8") as f:
-            env_content = f.read()
-
-        if f"{env_var_name}=" not in env_content:
-            # Append variable if not found
-            with open(env_file, "a", encoding="utf-8") as f:
-                f.write(
-                    f"\n# Remove the below to stop collecting data\n{env_var_name}={env_var_value}\n"
-                )
-            print(f"Added {env_var_name} to existing .env file")
-        else:
-            print(f"{env_var_name} already exists in .env file, not modifying")
+    # Ensure the data folder exists
+    data_dir = trainloop_dir / "data"
+    data_dir.mkdir(exist_ok=True)
+    events_dir = data_dir / "events"
+    events_dir.mkdir(exist_ok=True)
+    results_dir = data_dir / "results"
+    results_dir.mkdir(exist_ok=True)
+    registry_file = data_dir / "_registry.json"
+    registry_file.write_text("{}")
 
     # Install appropriate SDK based on project type
     install_appropriate_sdk(dest_dir)
@@ -72,7 +56,7 @@ def init_command():
     print("\nFollow the instructions in trainloop/README.md to start collecting data.")
 
 
-def install_appropriate_sdk(project_dir):
+def install_appropriate_sdk(project_dir: Path):
     """Detect project type and install appropriate SDK."""
     # Check for TypeScript/JavaScript project
     package_json = project_dir / "package.json"
@@ -97,7 +81,7 @@ def install_appropriate_sdk(project_dir):
                     "\nDetected Node.js project, installing trainloop-evals-sdk package..."
                 )
                 try:
-                    result = subprocess.run(
+                    subprocess.run(
                         ["npm", "install", "trainloop-evals-sdk"],
                         cwd=project_dir,
                         capture_output=True,
@@ -142,12 +126,8 @@ def install_appropriate_sdk(project_dir):
     else:
         # Create a new requirements.txt file if no project type detected
         print(
-            "\nNo package.json or requirements.txt found, creating requirements.txt..."
+            "\nNo package.json or requirements.txt found. Please add trainloop-evals-sdk to your project dependencies."
         )
-        with open(requirements_txt, "w", encoding="utf-8") as f:
-            f.write("# TrainLoop evaluation SDK\ntrainloop-evals-sdk\n")
-        print("Created requirements.txt with trainloop-evals-sdk dependency")
-        print("Please run: pip install -r requirements.txt")
 
 
 def print_directory_tree(directory, prefix="", is_last=True, is_root=True):
